@@ -1,2 +1,2 @@
 TOLERANCES = {"approximation": 10 ** -1, "input": 10 ** -3, "operation": 10**-6}
-UNITS = {"millimeters", "inches"}
+UNITS = {"mm", "in"}
